@@ -1,9 +1,10 @@
 package geolocate
 
 import (
-	"io/ioutil"
 	"net/http"
 	"time"
+
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 type FakeTransport struct {
@@ -14,7 +15,7 @@ type FakeTransport struct {
 func (txp FakeTransport) RoundTrip(req *http.Request) (*http.Response, error) {
 	time.Sleep(10 * time.Microsecond)
 	if req.Body != nil {
-		ioutil.ReadAll(req.Body)
+		netxlite.ReadAllContext(req.Context(), req.Body)
 		req.Body.Close()
 	}
 	if txp.Err != nil {
