@@ -3,8 +3,8 @@ package httpheader
 
 // UserAgent returns the User-Agent header used for measuring.
 func UserAgent() string {
-	// 13.2% as of Jan 24, 2021 according to https://techblog.willshouse.com/2012/01/03/most-common-user-agents/
-	const ua = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/96.0.4664.110 Safari/537.36"
+	// 7.6% as of Apr 12, 2022 according to https://techblog.willshouse.com/2012/01/03/most-common-user-agents/
+	const ua = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:98.0) Gecko/20100101 Firefox/98.0"
 	return ua
 }
 
@@ -12,5 +12,5 @@ func UserAgent() string {
 // pretent to be a command line HTTP client.
 func CLIUserAgent() string {
 	// here we always put the latest version of cURL.
-	return "curl/7.79.1"
+	return "curl/7.82.0"
 }
