@@ -6,7 +6,7 @@ import (
 	"testing"
 	"time"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/model"
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
 type FakeInputProcessorExperiment struct {
@@ -15,8 +15,8 @@ type FakeInputProcessorExperiment struct {
 	M         []*model.Measurement
 }
 
-func (fipe *FakeInputProcessorExperiment) MeasureWithContext(
-	ctx context.Context, input string) (*model.Measurement, error) {
+func (fipe *FakeInputProcessorExperiment) MeasureAsync(
+	ctx context.Context, input string) (<-chan *model.Measurement, error) {
 	if fipe.Err != nil {
 		return nil, fipe.Err
 	}
@@ -30,7 +30,12 @@ func (fipe *FakeInputProcessorExperiment) MeasureWithContext(
 	m.AddAnnotation("foo", "baz") // would be bar below
 	m.Input = model.MeasurementTarget(input)
 	fipe.M = append(fipe.M, m)
-	return m, nil
+	out := make(chan *model.Measurement)
+	go func() {
+		defer close(out)
+		out <- m
+	}()
+	return out, nil
 }
 
 func TestInputProcessorMeasurementFailed(t *testing.T) {
@@ -39,7 +44,7 @@ func TestInputProcessorMeasurementFailed(t *testing.T) {
 		Experiment: NewInputProcessorExperimentWrapper(
 			&FakeInputProcessorExperiment{Err: expected},
 		),
-		Inputs: []model.URLInfo{{
+		Inputs: []model.OOAPIURLInfo{{
 			URL: "https://www.kernel.org/",
 		}},
 	}
@@ -68,7 +73,7 @@ func TestInputProcessorSubmissionFailed(t *testing.T) {
 			"foo": "bar",
 		},
 		Experiment: NewInputProcessorExperimentWrapper(fipe),
-		Inputs: []model.URLInfo{{
+		Inputs: []model.OOAPIURLInfo{{
 			URL: "https://www.kernel.org/",
 		}},
 		Options: []string{"fake=true"},
@@ -117,7 +122,7 @@ func TestInputProcessorSaveOnDiskFailed(t *testing.T) {
 		Experiment: NewInputProcessorExperimentWrapper(
 			&FakeInputProcessorExperiment{},
 		),
-		Inputs: []model.URLInfo{{
+		Inputs: []model.OOAPIURLInfo{{
 			URL: "https://www.kernel.org/",
 		}},
 		Options: []string{"fake=true"},
@@ -140,7 +145,7 @@ func TestInputProcessorGood(t *testing.T) {
 	submitter := &FakeInputProcessorSubmitter{Err: nil}
 	ip := &InputProcessor{
 		Experiment: NewInputProcessorExperimentWrapper(fipe),
-		Inputs: []model.URLInfo{{
+		Inputs: []model.OOAPIURLInfo{{
 			URL: "https://www.kernel.org/",
 		}, {
 			URL: "https://www.slashdot.org/",
@@ -150,10 +155,11 @@ func TestInputProcessorGood(t *testing.T) {
 		Submitter: NewInputProcessorSubmitterWrapper(submitter),
 	}
 	ctx := context.Background()
-	if err := ip.Run(ctx); err != nil {
+	reason, err := ip.run(ctx)
+	if err != nil {
 		t.Fatal(err)
 	}
-	if ip.terminatedByMaxRuntime > 0 {
+	if reason != stopNormal {
 		t.Fatal("terminated by max runtime!?")
 	}
 	if len(fipe.M) != 2 || len(saver.M) != 2 || len(submitter.M) != 2 {
@@ -181,7 +187,7 @@ func TestInputProcessorMaxRuntime(t *testing.T) {
 	submitter := &FakeInputProcessorSubmitter{Err: nil}
 	ip := &InputProcessor{
 		Experiment: NewInputProcessorExperimentWrapper(fipe),
-		Inputs: []model.URLInfo{{
+		Inputs: []model.OOAPIURLInfo{{
 			URL: "https://www.kernel.org/",
 		}, {
 			URL: "https://www.slashdot.org/",
@@ -192,10 +198,11 @@ func TestInputProcessorMaxRuntime(t *testing.T) {
 		Submitter:  NewInputProcessorSubmitterWrapper(submitter),
 	}
 	ctx := context.Background()
-	if err := ip.Run(ctx); err != nil {
+	reason, err := ip.run(ctx)
+	if err != nil {
 		t.Fatal(err)
 	}
-	if ip.terminatedByMaxRuntime <= 0 {
+	if reason != stopMaxRuntime {
 		t.Fatal("not terminated by max runtime")
 	}
 }
