@@ -1,3 +1,4 @@
+//go:build !shaping
 // +build !shaping
 
 package dialer
@@ -5,17 +6,19 @@ package dialer
 import (
 	"context"
 	"net"
+
+	"github.com/ooni/probe-cli/v3/internal/model"
 )
 
-// ShapingDialer ensures we don't use too much bandwidth
+// shapingDialer ensures we don't use too much bandwidth
 // when using integration tests at GitHub. To select
 // the implementation with shaping use `-tags shaping`.
-type ShapingDialer struct {
-	Dialer
+type shapingDialer struct {
+	model.Dialer
 }
 
 // DialContext implements Dialer.DialContext
-func (d ShapingDialer) DialContext(
+func (d *shapingDialer) DialContext(
 	ctx context.Context, network, address string) (net.Conn, error) {
 	return d.Dialer.DialContext(ctx, network, address)
 }
