@@ -2,10 +2,11 @@ package httptransport
 
 import (
 	"context"
-	"io/ioutil"
 	"net"
 	"net/http"
 	"time"
+
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
 type FakeDialer struct {
@@ -19,18 +20,23 @@ func (d FakeDialer) DialContext(ctx context.Context, network, address string) (n
 }
 
 type FakeTransport struct {
+	Name string
 	Err  error
 	Func func(*http.Request) (*http.Response, error)
 	Resp *http.Response
 }
 
+func (txp FakeTransport) Network() string {
+	return txp.Name
+}
+
 func (txp FakeTransport) RoundTrip(req *http.Request) (*http.Response, error) {
 	time.Sleep(10 * time.Microsecond)
 	if txp.Func != nil {
 		return txp.Func(req)
 	}
 	if req.Body != nil {
-		ioutil.ReadAll(req.Body)
+		netxlite.ReadAllContext(req.Context(), req.Body)
 		req.Body.Close()
 	}
 	if txp.Err != nil {
