@@ -5,35 +5,20 @@ import (
 	"errors"
 	"testing"
 
-	"github.com/ooni/probe-cli/v3/internal/engine/netx/errorx"
 	"github.com/ooni/probe-cli/v3/internal/engine/netx/resolver"
+	"github.com/ooni/probe-cli/v3/internal/netxlite"
 )
 
-func TestResolverIsBogon(t *testing.T) {
-	if resolver.IsBogon("antani") != true {
-		t.Fatal("unexpected result")
-	}
-	if resolver.IsBogon("127.0.0.1") != true {
-		t.Fatal("unexpected result")
-	}
-	if resolver.IsBogon("1.1.1.1") != false {
-		t.Fatal("unexpected result")
-	}
-	if resolver.IsBogon("10.0.1.1") != true {
-		t.Fatal("unexpected result")
-	}
-}
-
 func TestBogonAwareResolverWithBogon(t *testing.T) {
 	r := resolver.BogonResolver{
 		Resolver: resolver.NewFakeResolverWithResult([]string{"127.0.0.1"}),
 	}
 	addrs, err := r.LookupHost(context.Background(), "dns.google.com")
-	if !errors.Is(err, errorx.ErrDNSBogon) {
+	if !errors.Is(err, netxlite.ErrDNSBogon) {
 		t.Fatal("not the error we expected")
 	}
-	if len(addrs) != 1 || addrs[0] != "127.0.0.1" {
-		t.Fatal("expected to see address here")
+	if len(addrs) > 0 {
+		t.Fatal("expected to see nil here")
 	}
 }
 
